@@ -5,16 +5,13 @@ import numpy as np
 import torch
 import torch.nn as nn
 from ray.rllib import SampleBatch
-from ray.rllib.evaluation.postprocessing import compute_advantages
-from ray.rllib.evaluation.postprocessing import Postprocessing
+from ray.rllib.evaluation.postprocessing import Postprocessing, compute_advantages
 from ray.rllib.utils import override
 
 import raylab.utils.dictionaries as dutil
 from raylab.agents.trpo.policy import LINESEARCH_DEFAULTS
-from raylab.options import configure
-from raylab.options import option
-from raylab.policy import learner_stats
-from raylab.policy import TorchPolicy
+from raylab.options import configure, option
+from raylab.policy import TorchPolicy, learner_stats
 from raylab.policy.action_dist import WrapStochasticPolicy
 from raylab.torch.nn.distributions import Normal
 from raylab.torch.optim import build_optimizer
@@ -22,7 +19,6 @@ from raylab.torch.optim.hessian_free import line_search
 from raylab.torch.optim.kfac import KFACMixin
 from raylab.utils.explained_variance import explained_variance
 
-
 DEFAULT_OPTIM_CONFIG = {
     "actor": {
         # Arguments for KFAC
